@@ -12,9 +12,6 @@ import pandas as pd
 from bccd.backend.fits import fits
 import bccd.backend.colors as colors
 from bccd.backend.PltTracker import PltTracker as plt
-
-from datetime import datetime
-from dateutil import tz
 from functools import partial
 
 # =========================================================================== # 
@@ -154,16 +151,8 @@ class fits_tab(object):
                   text='Exposure: %.3f s'%img.header['EXPOSURE']).grid(column=0,row=r,sticky=W); r+=1
         
         # show date and time, converted from utc to local
-        date = img.header['DATE-OBS']
-        from_zone = tz.tzutc()
-        to_zone = tz.gettz('Canada/Vancover')
-        
-        utc = datetime.strptime(date, '%Y-%m-%dT%H:%M:%S')
-        utc = utc.replace(tzinfo=from_zone)
-        local = utc.astimezone(to_zone)
-        
-        date = local.strftime("%Y-%m-%d")
-        time = local.strftime("%H:%M:%S")
+        date = img.datetime.strftime("%Y-%m-%d")
+        time = img.datetime.strftime("%H:%M:%S")
         
         ttk.Label(frame_column0,text=date).grid(column=0,row=r,sticky=W); r+=1
         ttk.Label(frame_column0,text=time).grid(column=0,row=r,sticky=W); r+=1
@@ -174,13 +163,13 @@ class fits_tab(object):
         frame_column1.grid(column=1,row=0,rowspan=10,sticky=(N,W),padx=5,pady=5)
         
         label_style = ttk.Label(frame_column1, text='Draw Style: ')
-        combo_style = ttk.Combobox(frame_column1, textvariable=self.style, 
+        self.combo_style = ttk.Combobox(frame_column1, textvariable=self.style, 
                                    state='readonly', width=20)
-        combo_style['values'] = tuple(self.styles.keys())
+        self.combo_style['values'] = tuple(self.styles.keys())
         
         r = 0
         label_style.grid(column=0,row=r,sticky=W)
-        combo_style.grid(column=1,row=r,sticky=W); r+=1
+        self.combo_style.grid(column=1,row=r,sticky=W); r+=1
         
         # black level
         label_black = ttk.Label(frame_column1,text='Black Value: ')
@@ -195,7 +184,7 @@ class fits_tab(object):
         button_black.grid(column=1,row=0,sticky=W, padx=2)
         
         # Inputs for draw style
-        combo_style.bind("<<ComboboxSelected>>", 
+        self.combo_style.bind("<<ComboboxSelected>>", 
                          partial(self.change_draw_fn, frame=frame_column1, row=r))
         r = self.input_place(frame_column1,r)+1
         
